pub struct AssetQuery {
pub address: String,
pub asset: AssetInfo,
}Fields
address: Stringasset: AssetInfoTrait Implementations
Sourceimpl Clone for AssetQuery
impl Clone for AssetQuery
Sourcefn clone(&self) -> AssetQuery
fn clone(&self) -> AssetQuery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssetQuery
impl Debug for AssetQuery
Sourceimpl<'de> Deserialize<'de> for AssetQuery
impl<'de> Deserialize<'de> for AssetQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AssetQuery
impl JsonSchema for AssetQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AssetQuery
impl PartialEq for AssetQuery
Sourceimpl Serialize for AssetQuery
impl Serialize for AssetQuery
impl StructuralPartialEq for AssetQuery