pub enum QueryMsg {
Show 17 variants
BlacklistedVoters {
start_after: Option<String>,
limit: Option<u32>,
},
TotalVamp {
time: Option<Time>,
},
TotalFixed {
time: Option<Time>,
},
LockVamp {
token_id: String,
time: Option<Time>,
},
LockInfo {
token_id: String,
time: Option<Time>,
},
Config {},
NftInfo {
token_id: String,
},
AllNftInfo {
token_id: String,
include_expired: Option<bool>,
},
OwnerOf {
token_id: String,
include_expired: Option<bool>,
},
Approval {
token_id: String,
spender: String,
include_expired: Option<bool>,
},
Approvals {
token_id: String,
include_expired: Option<bool>,
},
AllOperators {
owner: String,
include_expired: Option<bool>,
start_after: Option<String>,
limit: Option<u32>,
},
NumTokens {},
ContractInfo {},
Tokens {
owner: String,
start_after: Option<String>,
limit: Option<u32>,
},
AllTokens {
start_after: Option<String>,
limit: Option<u32>,
},
Minter {},
}Expand description
This structure describes the query messages available in the contract.
Variants
BlacklistedVoters
Return the blacklisted voters
TotalVamp
Return the current total amount of vAMP
TotalFixed
Return the current total amount of vAMP
LockVamp
Return the user’s current voting power (vAMP balance)
LockInfo
Return information about a user’s lock position
Config
Return the vAMP contract configuration
NftInfo
With MetaData Extension. Returns metadata about one particular token, based on ERC721 Metadata JSON Schema https://docs.opensea.io/docs/metadata-standards
{
“name”: “AllianceNFT # 1”,
“token_uri”: null,
“extension”: {
“image”: “https://ipfs.io/ipfs/{hash}”,
“description”: “Received for participating on Game Of Alliance”,
“name”: “AllianceNFT # 1”,
“attributes”: [{
“display_type” : null,
“trait_type”: “x”,
“value”: “1”
},{
“display_type” : null,
“trait_type”: “y”,
“value”: “1”
},{
“display_type” : null,
“trait_type”: “width”,
“value”: “120”
},{
“display_type” : null,
“trait_type”: “height”,
“value”: “120”
},{
“display_type” : null,
“trait_type”: “rarity”,
“value”: 11
}],
“image_data”: null,
“external_url”: null,
“background_color”: null,
“animation_url”: null,
“youtube_url”: null
}
}
AllNftInfo
With MetaData Extension.
Returns the result of both NftInfo and OwnerOf as one query as an optimization
Fields
OwnerOf
CW721 Queries Return the owner of the given token, error if token does not exist
Fields
Approval
Return operator that can access all of the owner’s tokens. Return the owner of the given token, error if token does not exist
Approvals
Return approvals that a token has
AllOperators
List all operators that can access all of the owner’s tokens
Fields
NumTokens
Total number of tokens issued
ContractInfo
With MetaData Extension.
Tokens
With Enumerable extension. Returns all tokens owned by the given address, [] if unset.
AllTokens
With Enumerable extension. Requires pagination. Lists all token_ids controlled by the contract.
Minter